@@ -4,24 +4,23 @@ XML::Easy::Element - abstract form of XML element
 
 =head1 SYNOPSIS
 
-    use XML::Easy::Element;
+	use XML::Easy::Element;
 
-    $element = XML::Easy::Element->new("a", { href => "#there" },
-		$content);
+	$element = XML::Easy::Element->new("a",
+			{ href => "#there" }, $content);
 
-    $type_name = $element->type_name;
-    $attributes = $element->attributes;
-    $href = $element->attribute("href");
-    $content = $element->content_object;
+	$type_name = $element->type_name;
+	$attributes = $element->attributes;
+	$href = $element->attribute("href");
+	$content = $element->content_object;
 
 =head1 DESCRIPTION
 
 An object of this class represents an XML element, a node in the tree
-making up an XML document.  This is in an abstract form, intended
-for general manipulation.  It is completely isolated from the textual
-representation of XML, and holds only the meaningful content of the
-element.  The data in an element object cannot be modified: different
-data requires the creation of a new object.
+making up an XML document.  This is in an abstract form, completely
+isolated from the textual representation of XML, holding only the
+meaningful content of the element.  This is a suitable form for
+application code to manipulate an XML representation of application data.
 
 The properties of an XML element are of three kinds.  Firstly, the element
 has exactly one type, which is referred to by a name.  Secondly, the
@@ -38,6 +37,10 @@ almost all Unicode characters, with only a few characters (such as most
 of the ASCII control characters) prohibited by the specification from
 being directly represented in XML.
 
+An abstract element object cannot be modified.  Once created, its
+properties are fixed.  Tasks that you might think of as "modifying an
+XML node" actually involve creating a new node.
+
 This class is not meant to be subclassed.  XML elements are unextendable,
 dumb data.  Element objects are better processed using the functions in
 L<XML::Easy::NodeBasics> than using the methods of this class.
@@ -46,46 +49,12 @@ L<XML::Easy::NodeBasics> than using the methods of this class.
 
 package XML::Easy::Element;
 
-{ use 5.010001; }
 use warnings;
 use strict;
 
-use XML::Easy::Content 0.007 ();
-
-our $VERSION = "0.011_001";
-
-eval { local $SIG{__DIE__};
-	require XSLoader;
-	XSLoader::load("XML::Easy", $VERSION) unless defined &new;
-};
-
-if($@ eq "") {
-	close(DATA);
-} else {
-	(my $filename = __FILE__) =~ tr# -~##cd;
-	local $/ = undef;
-	my $pp_code = "#line 83 \"$filename\"\n".<DATA>;
-	close(DATA);
-	{
-		local $SIG{__DIE__};
-		eval $pp_code;
-	}
-	die $@ if $@ ne "";
-}
-
-*content = \&content_twine;
-
-1;
-
-__DATA__
-
-# Note perl bug: a bug in perl 5.8.{0..6} screws up __PACKAGE__ (used below)
-# for the eval.  Explicit package declaration here fixes it.
-package XML::Easy::Element;
-
-use Params::Classify 0.000 qw(is_string is_ref);
-use XML::Easy::Classify 0.001 qw(check_xml_attributes check_xml_content_object);
-use XML::Easy::Syntax 0.000 qw($xml10_name_rx);
+use Params::Classify 0.000 qw(is_string is_ref is_strictly_blessed);
+use XML::Easy::Content 0.001 ();
+use XML::Easy::Syntax 0.000 qw($xml10_char_rx $xml10_name_rx);
 
 BEGIN {
 	if(eval { local $SIG{__DIE__};
@@ -98,6 +67,8 @@ BEGIN {
 	}
 }
 
+our $VERSION = "0.001";
+
 sub _throw_data_error($) {
 	my($msg) = @_;
 	die "invalid XML data: $msg\n";
@@ -113,9 +84,8 @@ Constructs and returns a new element object with the specified properties.
 I<TYPE_NAME> must be a string.  I<ATTRIBUTES> must be a reference
 to a hash in the same form that is returned by the accessor method
 C<attributes> (below).  I<CONTENT> must be a reference to either an
-L<XML::Easy::Content> object or a twine array
-(see L<XML::Easy::NodeBasics/Twine>).
-All are checked for validity, against
+L<XML::Easy::Content> object or an array of the type that can be passed
+to that class's C<new> constructor.  All are checked for validity, against
 the XML 1.0 specification, and the function C<die>s if any are invalid.
 
 =cut
@@ -125,9 +95,7 @@ sub new {
 	_throw_data_error("element type name isn't a string")
 		unless is_string($type_name);
 	{
-		no if "$]" < 5.017002, qw(warnings utf8);
-		no if "$]" >= 5.023006 && "$]" < 5.027001,
-			qw(warnings deprecated);
+		no warnings "utf8";
 		_throw_data_error("illegal element type name")
 			unless $type_name =~ /\A$xml10_name_rx\z/o;
 	}
@@ -136,12 +104,19 @@ sub new {
 	$attrs = { %$attrs };
 	_set_readonly(\$_) foreach values %$attrs;
 	_set_readonly($attrs);
-	check_xml_attributes($attrs);
-	if(is_ref($content, "ARRAY")) {
-		$content = XML::Easy::Content->new($content);
-	} else {
-		check_xml_content_object($content);
+	foreach(sort keys %$attrs) {
+		no warnings "utf8";
+		_throw_data_error("illegal attribute name")
+			unless /\A$xml10_name_rx\z/o;
+		_throw_data_error("character data isn't a string")
+			unless is_string($attrs->{$_});
+		_throw_data_error("character data contains illegal character")
+			unless $attrs->{$_} =~ /\A$xml10_char_rx*\z/o;
 	}
+	$content = XML::Easy::Content->new($content)
+		if is_ref($content, "ARRAY");
+	_throw_data_error("content data isn't a content chunk")
+		unless is_strictly_blessed($content, "XML::Easy::Content");
 	my $self = bless([ $type_name, $attrs, $content ], __PACKAGE__);
 	_set_readonly(\$_) foreach @$self;
 	_set_readonly($self);
@@ -168,11 +143,6 @@ Returns a reference to a hash encapsulating the element's attributes.
 In the hash, each key is an attribute name, and the corresponding value
 is the attribute's value as a string.
 
-The returned hash must not be subsequently modified.  If possible, it
-will be marked as read-only in order to prevent modification.  As a side
-effect, the read-only-ness may make lookup of any non-existent attribute
-generate an exception rather than returning C<undef>.
-
 =cut
 
 sub attributes { $_[0]->[1] }
@@ -190,9 +160,7 @@ sub attribute {
 	_throw_data_error("attribute name isn't a string")
 		unless is_string($_[1]);
 	{
-		no if "$]" < 5.017002, qw(warnings utf8);
-		no if "$]" >= 5.023006 && "$]" < 5.027001,
-			qw(warnings deprecated);
+		no warnings "utf8";
 		_throw_data_error("illegal attribute name")
 			unless $_[1] =~ /\A$xml10_name_rx\z/o;
 	}
@@ -208,26 +176,21 @@ the element's content.
 
 sub content_object { $_[0]->[2] }
 
-=item $element->content_twine
+=item $element->content
 
-Returns a reference to a twine array (see L<XML::Easy::NodeBasics/Twine>)
-listing the element's content.
-
-The returned array must not be subsequently modified.  If possible,
-it will be marked as read-only in order to prevent modification.
+Returns a reference to an array listing the element's content in
+the canonical form that is returned by the C<content> accessor of
+L<XML::Easy::Content>.
 
 =cut
 
-sub content_twine {
+sub content {
 	my $content = $_[0]->[2];
-	check_xml_content_object($content);
-	return $content->twine;
+	_throw_data_error("content data isn't a content chunk")
+		unless is_strictly_blessed($content, "XML::Easy::Content");
+	return $content->content;
 }
 
-=item $element->content
-
-Deprecated alias for the L</content_twine> method.
-
 =back
 
 =head1 SEE ALSO
@@ -241,10 +204,9 @@ Andrew Main (Zefram) <zefram@fysh.org>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2008, 2009 PhotoBox Ltd
+Copyright (C) 2008 PhotoBox Ltd
 
-Copyright (C) 2009, 2010, 2011, 2017
-Andrew Main (Zefram) <zefram@fysh.org>
+Copyright (C) 2009 Andrew Main (Zefram) <zefram@fysh.org>
 
 =head1 LICENSE
 
