@@ -4,31 +4,29 @@ XML::Easy::Syntax - excruciatingly correct XML syntax
 
 =head1 SYNOPSIS
 
-    use XML::Easy::Syntax qw($xml10_name_rx);
-    if($name =~ /\A$xml10_name_rx\z/o) { ...
-    # and many other regular expressions
+	use XML::Easy::Syntax qw($xml10_name_rx);
+	if($name =~ /\A$xml10_name_rx\z/o) { ...
+	# and many other regular expressions
 
 =head1 DESCRIPTION
 
-This module supplies Perl regular expressions describing the grammar of
-XML 1.0.  This is intended to support doing irregular things with XML,
-rather than for normal parsing.
+This module supplies Perl regular expressions encompassing the grammar
+of XML 1.0, except for document type declarations and DTDs.  They can
+be used to construct an XML parser, but it is generally recommended
+to use a pre-existing parser (such as the one in L<XML::Easy::Text>)
+when doing ordinary XML processing.  This module is most useful when
+doing irregular things with XML.
 
-These regular expressions encompass the entire XML grammar except for
-document type declarations and DTDs.
 This document assumes general familiarity with XML.
 
 =cut
 
 package XML::Easy::Syntax;
 
-{ use 5.010001; }
 use warnings;
 use strict;
 
-our $VERSION = "0.011_001";
-
-use parent "Exporter";
+use base "Exporter";
 our @EXPORT_OK = qw(
 	$xml10_char_rx $xml10_s_rx $xml10_eq_rx
 	$xml10_namestartchar_rx $xml10_namechar_rx
@@ -47,6 +45,8 @@ our @EXPORT_OK = qw(
 	$xml10_prolog_xdtd_rx $xml10_document_xdtd_rx $xml10_extparsedent_rx
 );
 
+our $VERSION = "0.001";
+
 sub _charclass_regexp($) {
 	my($class) = @_;
 	$class =~ tr/ \t\n//d;
@@ -721,7 +721,7 @@ our $xml10_reference_rx = qr/$xml10_entityref_rx|$xml10_charref_rx/o;
 =item $xml10_chardata_rx
 
 Ordinary literal character data.  This consists of zero or more acceptable
-characters, other than the metacharacters "B<< < >>" and "B<&>", and
+charaters, other than the metacharacters "B<< < >>" and "B<&>", and
 not including "B<< ]]> >>" as a subsequence.  Such data stands for
 itself when it appears between the start and end tags of an element,
 where it can be interspersed with references, CDATA sections, comments,
@@ -748,7 +748,7 @@ our $xml10_chardata_rx = qr/(?:
 =item $xml10_cdata_rx
 
 Literal character data in a CDATA section.  This consists of zero or
-more acceptable characters, not including "B<< ]]> >>" as a subsequence.
+more acceptable charaters, not including "B<< ]]> >>" as a subsequence.
 Unlike ordinary literal character data, the characters "B<< < >>" and
 "B<&>" are not metacharacters here.  Such data stands for itself when
 it appears within a CDATA section.
@@ -1063,7 +1063,7 @@ This is either a comment, a processing instruction, or a stretch of
 whitespace.
 
 Beware in using a pattern such as C<$xml10_misc_rx*>.  It could match
-a string of whitespace characters in many ways, leading to exponential
+a string of whitespace charaters in many ways, leading to exponential
 behaviour if it becomes necessary to backtrack.  This can be avoided by
 using the C<$xml10_miscseq_rx> pattern (below).
 
@@ -1137,8 +1137,7 @@ In some cases, but not all, a false match failure is preceded by a warning
 "Complex regular subexpression recursion limit (32766) exceeded".
 
 This bug is present, in various forms, in all perl versions up to at
-least 5.8.9 and 5.10.0.  Pre-5.10 perls may also overflow their stack
-space, in similar circumstances, if a resource limit is imposed.
+least 5.8.9 and 5.10.0.
 
 There is no known feasible workaround for this perl bug.  The regular
 expressions supplied by this module will therefore, unavoidably, fail
@@ -1162,8 +1161,7 @@ Andrew Main (Zefram) <zefram@fysh.org>
 
 Copyright (C) 2008, 2009 PhotoBox Ltd
 
-Copyright (C) 2009, 2010, 2011, 2017
-Andrew Main (Zefram) <zefram@fysh.org>
+Copyright (C) 2009 Andrew Main (Zefram) <zefram@fysh.org>
 
 =head1 LICENSE
 
