@@ -4,35 +4,38 @@ XML::Easy::Text - XML parsing and serialisation
 
 =head1 SYNOPSIS
 
-    use XML::Easy::Text qw(
-	xml10_read_content_object xml10_read_element
-	xml10_read_document xml10_read_extparsedent_object);
+	use XML::Easy::Text qw(
+		xml10_read_content_object xml10_read_element
+		xml10_read_document xml10_read_extparsedent_object
+	);
 
-    $content = xml10_read_content_object($text);
-    $element = xml10_read_element($text);
-    $element = xml10_read_document($text);
-    $content = xml10_read_extparsedent_object($text);
+	$content = xml10_read_content_object($text);
+	$element = xml10_read_element($text);
+	$element = xml10_read_document($text);
+	$content = xml10_read_extparsedent_object($text);
 
-    use XML::Easy::Text qw(
-	xml10_write_content xml10_write_element
-	xml10_write_document xml10_write_extparsedent);
+	use XML::Easy::Text qw(
+		xml10_write_content xml10_write_element
+		xml10_write_document xml10_write_extparsedent
+	);
 
-    $text = xml10_write_content($content);
-    $text = xml10_write_element($element);
-    $text = xml10_write_document($element, "UTF-8");
-    $text = xml10_write_extparsedent($content, "UTF-8");
+	$text = xml10_write_content($content);
+	$text = xml10_write_element($element);
+	$text = xml10_write_document($element, "UTF-8");
+	$text = xml10_write_extparsedent($content, "UTF-8");
 
 =head1 DESCRIPTION
 
 This module supplies functions that parse and serialise XML data
-according to the XML 1.0 specification.
+according to the XML 1.0 specification.  The functions are implemented
+in C for performance, with a pure Perl backup version (which has good
+performance compared to other pure Perl parsers) for systems that can't
+handle XS modules.
 
-This module is oriented towards the use of XML to represent data
-for interchange purposes, rather than the use of XML as markup of
-principally textual data.  It does not perform any schema processing,
-and does not interpret DTDs or any other kind of schema.  It adheres
-strictly to the XML specification, in all its awkward details, except
-for the aforementioned DTDs.
+This module is oriented towards the use of XML to represent data for
+interchange purposes, rather than the use of XML as markup of principally
+textual data.  It does not perform any schema processing, and does not
+interpret DTDs or any other kind of schema.
 
 XML data in memory is represented using a tree of
 L<XML::Easy::Content> and L<XML::Easy::Element>
@@ -42,40 +45,31 @@ from the textual syntax.
 These node trees are readily manipulated by the functions
 in L<XML::Easy::NodeBasics>.
 
-The functions of this module are implemented
-in C for performance, with a pure Perl backup version (which has good
-performance compared to other pure Perl parsers) for systems that can't
-handle XS modules.
-
 =cut
 
 package XML::Easy::Text;
 
-{ use 5.010001; }
 use warnings;
 use strict;
 
-use XML::Easy::Content 0.007 ();
-use XML::Easy::Element 0.007 ();
+use XML::Easy::Content 0.001 ();
+use XML::Easy::Element 0.001 ();
 
-our $VERSION = "0.011_001";
+our $VERSION = "0.001";
 
-use parent "Exporter";
+use base "Exporter";
 our @EXPORT_OK = qw(
-	xml10_read_content_object xml10_read_content_twine
-	xml10_read_content
+	xml10_read_content_object xml10_read_content
 	xml10_read_element
 	xml10_read_document
-	xml10_read_extparsedent_object xml10_read_extparsedent_twine
-	xml10_read_extparsedent
+	xml10_read_extparsedent_object xml10_read_extparsedent
 	xml10_write_content xml10_write_element
 	xml10_write_document xml10_write_extparsedent
 );
 
 eval { local $SIG{__DIE__};
 	require XSLoader;
-	XSLoader::load("XML::Easy", $VERSION)
-		unless defined &xml10_write_document;
+	XSLoader::load("XML::Easy", $VERSION);
 };
 
 if($@ eq "") {
@@ -83,7 +77,7 @@ if($@ eq "") {
 } else {
 	(my $filename = __FILE__) =~ tr# -~##cd;
 	local $/ = undef;
-	my $pp_code = "#line 98 \"$filename\"\n".<DATA>;
+	my $pp_code = "#line 92 \"$filename\"\n".<DATA>;
 	close(DATA);
 	{
 		local $SIG{__DIE__};
@@ -92,9 +86,6 @@ if($@ eq "") {
 	die $@ if $@ ne "";
 }
 
-*xml10_read_content = \&xml10_read_content_twine;
-*xml10_read_extparsedent = \&xml10_read_extparsedent_twine;
-
 1;
 
 __DATA__
@@ -168,7 +159,7 @@ sub _parse_reference($) {
 		my $v = $1;
 		_throw_wfc_error("invalid character in character reference")
 			unless $v =~ /\A0*(.{1,6})\z/s;
-		no if "$]" < 5.017002, qw(warnings utf8);
+		no warnings "utf8";
 		my $c = chr(hex($v));
 		_throw_wfc_error("invalid character in character reference")
 			unless $c =~ /\A$xml10_char_rx\z/o;
@@ -177,7 +168,7 @@ sub _parse_reference($) {
 		my $v = $1;
 		_throw_wfc_error("invalid character in character reference")
 			unless $v =~ /\A0*(.{1,7})\z/s;
-		no if "$]" < 5.017002, qw(warnings utf8);
+		no warnings "utf8";
 		my $c = chr($v);
 		_throw_wfc_error("invalid character in character reference")
 			unless $c =~ /\A$xml10_char_rx\z/o;
@@ -213,9 +204,9 @@ sub _parse_attvalue($) {
 
 sub _parse_element($);
 
-sub _parse_twine($) {
+sub _parse_content_array($) {
 	my($rtext) = @_;
-	my @twine = ("");
+	my @content = ("");
 	while(1) {
 		# Note perl bug: in some versions of perl, including 5.8.8
 		# and 5.10.0, the "+" in the character-data regexp acts
@@ -237,28 +228,28 @@ sub _parse_twine($) {
 				if $value =~ s/(?!\A)(\x{d}|\]\]?)\z//;
 			_throw_syntax_error($rtext) if $value =~ /\]\]>/;
 			$value =~ s/\x{d}\x{a}?/\x{a}/g;
-			$twine[-1] .= $value;
+			$content[-1] .= $value;
 		} elsif($$rtext =~ m#\G(?=<[^/?!])#gc) {
-			push @twine, _parse_element($rtext), "";
+			push @content, _parse_element($rtext), "";
 		} elsif($$rtext =~ /\G(?=&)/gc) {
-			$twine[-1] .= _parse_reference($rtext);
+			$content[-1] .= _parse_reference($rtext);
 		} elsif($$rtext =~ /\G<!\[CDATA\[($xml10_char_rx*?)\]\]>/ogc) {
 			my $value = $1;
 			$value =~ s/\x{d}\x{a}?/\x{a}/g;
-			$twine[-1] .= $value;
+			$content[-1] .= $value;
 		} elsif($$rtext =~ /\G(?:$xml10_pi_rx|$xml10_comment_rx)/ogc) {
 			# no content
 		} else {
-			return \@twine;
+			return \@content;
 		}
 	}
 }
 
-sub _parse_contentobject($) {
-	return XML::Easy::Content->new(_parse_twine($_[0]));
+sub _parse_content_object($) {
+	return XML::Easy::Content->new(_parse_content_array($_[0]));
 }
 
-my $empty_contentobject = XML::Easy::Content->new([""]);
+my $empty_content_object = XML::Easy::Content->new([""]);
 
 sub _parse_element($) {
 	my($rtext) = @_;
@@ -273,9 +264,9 @@ sub _parse_element($) {
 	$$rtext =~ m#\G(/)?>#gc or _throw_syntax_error($rtext);
 	my $content;
 	if(defined $1) {
-		$content = $empty_contentobject;
+		$content = $empty_content_object;
 	} else {
-		$content = _parse_contentobject($rtext);
+		$content = _parse_content_object($rtext);
 		$$rtext =~ m#\G</($xml10_name_rx)$xml10_s_rx?>#gc
 			or _throw_syntax_error($rtext);
 		_throw_wfc_error("mismatched tags") unless $1 eq $ename;
@@ -302,36 +293,37 @@ the full XML grammar.
 sub xml10_read_content_object($) {
 	_throw_data_error("text isn't a string") unless is_string($_[0]);
 	my($text) = @_;
-	my $content = _parse_contentobject(\$text);
+	my $content = _parse_content_object(\$text);
 	$text =~ /\G\z/gc or _throw_syntax_error(\$text);
 	return $content;
 }
 
-=item xml10_read_content_twine(TEXT)
+=item xml10_read_content(TEXT)
 
-Performs the same parsing job as L</xml10_read_content_object>,
-but returns the resulting content chunk in the form of twine
-(see L<XML::Easy::NodeBasics/Twine>) rather than a content object.
+I<TEXT> must be a character string.  It is parsed against the B<content>
+production of the XML 1.0 grammar; i.e., as a sequence of the kind of
+matter that can appear between the start-tag and end-tag of an element.
+Returns a reference to an array listing the content in
+the canonical form that is returned by the C<content> accessor of
+L<XML::Easy::Content>.
 
-The returned array must not be subsequently modified.  If possible,
-it will be marked as read-only in order to prevent modification.
+Normally one would not want to use this function directly, but prefer the
+higher-level C<xml10_read_document> function.  This function exists for
+the construction of custom XML parsers in situations that don't match
+the full XML grammar.
 
 =cut
 
-sub xml10_read_content_twine($) {
+sub xml10_read_content($) {
 	_throw_data_error("text isn't a string") unless is_string($_[0]);
 	my($text) = @_;
-	my $twine = _parse_twine(\$text);
+	my $content = _parse_content_array(\$text);
 	$text =~ /\G\z/gc or _throw_syntax_error(\$text);
-	_set_readonly(\$_) foreach @$twine;
-	_set_readonly($twine);
-	return $twine;
+	_set_readonly(\$_) foreach @$content;
+	_set_readonly($content);
+	return $content;
 }
 
-=item xml10_read_content(TEXT)
-
-Deprecated alias for L</xml10_read_content_twine>.
-
 =item xml10_read_element(TEXT)
 
 I<TEXT> must be a character string.  It is parsed against the B<element>
@@ -399,37 +391,39 @@ sub xml10_read_extparsedent_object($) {
 	_throw_data_error("text isn't a string") unless is_string($_[0]);
 	my($text) = @_;
 	$text =~ /\A$xml10_textdecl_rx/gc;
-	my $content = _parse_contentobject(\$text);
+	my $content = _parse_content_object(\$text);
 	$text =~ /\G\z/gc or _throw_syntax_error(\$text);
 	return $content;
 }
 
-=item xml10_read_extparsedent_twine(TEXT)
+=item xml10_read_extparsedent(TEXT)
 
-Performs the same parsing job as L</xml10_read_extparsedent_object>,
-but returns the resulting content chunk in the form of twine
-(see L<XML::Easy::NodeBasics/Twine>) rather than a content object.
+I<TEXT> must be a character string.  It is parsed against the
+B<extParsedEnt> production of the XML 1.0 grammar; i.e., as a sequence
+of content (containing character data and subelements), possibly
+headed by a text declaration (which is similar to, but not the same
+as, an XML declaration).
+Returns a reference to an array listing the content in
+the canonical form that is returned by the C<content> accessor of
+L<XML::Easy::Content>.
 
-The returned array must not be subsequently modified.  If possible,
-it will be marked as read-only in order to prevent modification.
+This is a relatively obscure part of the XML grammar, used when a
+subpart of a document is stored in a separate file.  You're more likely
+to require the C<xml10_read_document> function.
 
 =cut
 
-sub xml10_read_extparsedent_twine($) {
+sub xml10_read_extparsedent($) {
 	_throw_data_error("text isn't a string") unless is_string($_[0]);
 	my($text) = @_;
 	$text =~ /\A$xml10_textdecl_rx/gc;
-	my $twine = _parse_twine(\$text);
+	my $content = _parse_content_array(\$text);
 	$text =~ /\G\z/gc or _throw_syntax_error(\$text);
-	_set_readonly(\$_) foreach @$twine;
-	_set_readonly($twine);
-	return $twine;
+	_set_readonly(\$_) foreach @$content;
+	_set_readonly($content);
+	return $content;
 }
 
-=item xml10_read_extparsedent(TEXT)
-
-Deprecated alias for L</xml10_read_extparsedent_twine>.
-
 =back
 
 =head2 Serialisation
@@ -453,8 +447,7 @@ sub _serialise_chardata($$) {
 	my($rtext, $str) = @_;
 	_throw_data_error("character data isn't a string")
 		unless is_string($str);
-	no if "$]" < 5.017002, qw(warnings utf8);
-	no if "$]" >= 5.023006 && "$]" < 5.027001, qw(warnings deprecated);
+	no warnings "utf8";
 	while($str !~ /\G\z/gc) {
 		# Note perl bug: in some versions of perl, including 5.8.8
 		# and 5.10.0, the "+" in the plain-character regexp acts
@@ -485,32 +478,32 @@ sub _serialise_chardata($$) {
 
 sub _serialise_element($$);
 
-sub _serialise_twine($$) {
-	my($rtext, $twine) = @_;
+sub _serialise_content_array($$) {
+	my($rtext, $contarray) = @_;
 	_throw_data_error("content array isn't an array")
-		unless is_ref($twine, "ARRAY");
+		unless is_ref($contarray, "ARRAY");
 	_throw_data_error("content array has even length")
-		unless @$twine % 2 == 1;
-	_serialise_chardata($rtext, $twine->[0]);
-	my $ncont = @$twine;
+		unless @$contarray % 2 == 1;
+	_serialise_chardata($rtext, $contarray->[0]);
+	my $ncont = @$contarray;
 	for(my $i = 1; $i != $ncont; ) {
-		_serialise_element($rtext, $twine->[$i++]);
-		_serialise_chardata($rtext, $twine->[$i++]);
+		_serialise_element($rtext, $contarray->[$i++]);
+		_serialise_chardata($rtext, $contarray->[$i++]);
 	}
 }
 
-sub _serialise_contentobject($$) {
+sub _serialise_content_object($$) {
 	my($rtext, $content) = @_;
 	_throw_data_error("content data isn't a content chunk")
 		unless is_strictly_blessed($content, "XML::Easy::Content");
-	_serialise_twine($rtext, $content->twine);
+	_serialise_content_array($rtext, $content->content);
 }
 
-sub _serialise_eithercontent($$) {
+sub _serialise_content_eitherway($$) {
 	if(is_ref($_[1], "ARRAY")) {
-		goto &_serialise_twine;
+		goto &_serialise_content_array;
 	} else {
-		goto &_serialise_contentobject;
+		goto &_serialise_content_object;
 	}
 }
 
@@ -518,8 +511,7 @@ sub _serialise_attvalue($$) {
 	my($rtext, $str) = @_;
 	_throw_data_error("character data isn't a string")
 		unless is_string($str);
-	no if "$]" < 5.017002, qw(warnings utf8);
-	no if "$]" >= 5.023006 && "$]" < 5.027001, qw(warnings deprecated);
+	no warnings "utf8";
 	while($str !~ /\G\z/gc) {
 		# Note perl bug: in some versions of perl, including 5.8.8
 		# and 5.10.0, the "+" in the plain-character regexp acts
@@ -556,9 +548,7 @@ sub _serialise_element($$) {
 	_throw_data_error("element type name isn't a string")
 		unless is_string($type_name);
 	{
-		no if "$]" < 5.017002, qw(warnings utf8);
-		no if "$]" >= 5.023006 && "$]" < 5.027001,
-			qw(warnings deprecated);
+		no warnings "utf8";
 		_throw_data_error("illegal element type name")
 			unless $type_name =~ /\A$xml10_name_rx\z/o;
 	}
@@ -568,9 +558,7 @@ sub _serialise_element($$) {
 		unless is_ref($attributes, "HASH");
 	foreach(sort keys %$attributes) {
 		{
-			no if "$]" < 5.017002, qw(warnings utf8);
-			no if "$]" >= 5.023006 && "$]" < 5.027001,
-				qw(warnings deprecated);
+			no warnings "utf8";
 			_throw_data_error("illegal attribute name")
 				unless /\A$xml10_name_rx\z/o;
 		}
@@ -578,13 +566,13 @@ sub _serialise_element($$) {
 		_serialise_attvalue($rtext, $attributes->{$_});
 		$$rtext .= "\"";
 	}
-	my $twine = $elem->content_twine;
-	if(is_ref($twine, "ARRAY") && @$twine == 1 &&
-			is_string($twine->[0]) && $twine->[0] eq "") {
+	my $content = $elem->content;
+	if(is_ref($content, "ARRAY") && @$content == 1 &&
+			is_string($content->[0]) && $content->[0] eq "") {
 		$$rtext .= "/>";
 	} else {
 		$$rtext .= ">";
-		_serialise_twine($rtext, $twine);
+		_serialise_content_array($rtext, $content);
 		$$rtext .= "</".$type_name.">";
 	}
 }
@@ -594,15 +582,16 @@ sub _serialise_element($$) {
 =item xml10_write_content(CONTENT)
 
 I<CONTENT> must be a reference to either an L<XML::Easy::Content>
-object or a twine array (see L<XML::Easy::NodeBasics/Twine>).
-The XML 1.0 textual representation of that content is returned.
+object or an array of the type that can be passed to that class's
+C<new> constructor.  The XML 1.0 textual representation of that content
+is returned.
 
 =cut
 
 sub xml10_write_content($) {
 	my($content) = @_;
 	my $text = "";
-	_serialise_eithercontent(\$text, $content);
+	_serialise_content_eitherway(\$text, $content);
 	return $text;
 }
 
@@ -639,9 +628,7 @@ sub xml10_write_document($;$) {
 		_throw_data_error("encoding name isn't a string")
 			unless is_string($encname);
 		{
-			no if "$]" < 5.017002, qw(warnings utf8);
-			no if "$]" >= 5.023006 && "$]" < 5.027001,
-				qw(warnings deprecated);
+			no warnings "utf8";
 			_throw_data_error("illegal encoding name")
 				unless $encname =~ /\A$xml10_encname_rx\z/;
 		}
@@ -656,8 +643,8 @@ sub xml10_write_document($;$) {
 =item xml10_write_extparsedent(CONTENT[, ENCODING])
 
 I<CONTENT> must be a reference to either an L<XML::Easy::Content>
-object or a twine array (see L<XML::Easy::NodeBasics/Twine>).
-The XML 1.0 textual form of an external
+object or an array of the type that can be passed to that class's C<new>
+constructor.  The XML 1.0 textual form of an external
 parsed entity encapsulating that content is returned.  If I<ENCODING> is
 supplied, it must be a valid character encoding name, and the returned
 entity includes a text declaration that specifies the encoding name in
@@ -673,15 +660,13 @@ sub xml10_write_extparsedent($;$) {
 		_throw_data_error("encoding name isn't a string")
 			unless is_string($encname);
 		{
-			no if "$]" < 5.017002, qw(warnings utf8);
-			no if "$]" >= 5.023006 && "$]" < 5.027001,
-				qw(warnings deprecated);
+			no warnings "utf8";
 			_throw_data_error("illegal encoding name")
 				unless $encname =~ /\A$xml10_encname_rx\z/;
 		}
 		$text .= "<?xml encoding=\"".$encname."\"?>";
 	}
-	_serialise_eithercontent(\$text, $content);
+	_serialise_content_eitherway(\$text, $content);
 	return $text;
 }
 
@@ -701,8 +686,7 @@ Andrew Main (Zefram) <zefram@fysh.org>
 
 Copyright (C) 2008, 2009 PhotoBox Ltd
 
-Copyright (C) 2009, 2010, 2011, 2017
-Andrew Main (Zefram) <zefram@fysh.org>
+Copyright (C) 2009 Andrew Main (Zefram) <zefram@fysh.org>
 
 =head1 LICENSE
 
